# omega_fit_regional.R
# Fit omega for multiple units within a region 

# clean up
rm(list=ls())
graphics.off()

# install required packages/ function files
source('budyko_single_fit.R')
source('budyko_m1.R')

# read in the attached PE/Rainfall/etc. data
potentialevap       <-  unlist(read.table("PET_83_93.txt", skip=0))
precip              <-  unlist(read.table("MAP_83_93.txt", skip=0))
actualevap          <-  unlist(read.table("AET_83_93.txt", skip=0))
aridityind          <-  potentialevap/precip
evapratio           <-  actualevap/precip

# define number of units
numunits            <-  length(evapratio)

# remove NaNs if any
nanaridity          <-  which(is.nan(aridityind)==TRUE)
nanevapratio        <-  which(is.nan(evapratio)==TRUE)
allnans             <-  union(nanaridity, nanevapratio)
# set all units for which any data is missing to NaN
aridityind[allnans] <-  NaN
evapratio[allnans]  <-  NaN

# remove invalid data points
# 1. remove all units not obeying water balance
rm1                 <- which(evapratio >= 1)
# 2. remove all units not obeying energy balance
rm2                 <- which(evapratio/aridityind >= 1)
rmall               <- c(rm1, rm2)
# replace invalid values by NaN
evapratio[rmall]    <- NaN
aridityind[rmall]   <- NaN

# omegafit contains the fitted omega values for each unit
# define vector
omegafit            <- array(NaN, c(numunits, 1))

# fit each district one by one
for (unitind in 1:numunits) {
  if (is.nan(evapratio[unitind])==FALSE) {
    omegafit[unitind] <- budyko_single_fit(aridityind[unitind], evapratio[unitind])
  }
}
output                <- list()
output$actualevap     <- actualevap
output$potentialevap  <- potentialevap
output$precip         <- precip
output$aridityind     <- aridityind
output$evapratio      <- evapratio
output$omegafit       <- omegafit
save(output,file='omegafit.RData')